<?php

class ControladorEmpleado{

	/*=============================================
	REGISTRO DE TRABAJADOR
	=============================================*/
	static public function ctrCrearEmpleado(){
		if(isset($_POST["nuevoNombre"])){
			if(preg_match('/[a-zA-Z0-9 ]/', $_POST["nuevoNombre"]) &&
				preg_match('/^[0-9]{8}+$/', $_POST["nuevoDNI"])){
				$tabla = "empleado";
				$estado = 1;
				$datos = array("dni" => trim($_POST["nuevoDNI"]),
					           "nombre" =>  strtoupper(trim($_POST["nuevoNombre"])),
							   "direccion" =>  strtoupper(trim($_POST["nuevoDireccion"])),
							   "telefono" => trim($_POST["nuevoTelefono1"]),
							   "email" => filter_var($_POST["nuevoEmail"], FILTER_SANITIZE_EMAIL),
							   "fecha_ingreso" => $_POST["nuevoFecha"],				         
							   "estado"=>$estado);
				$respuesta = ModeloEmpleado::mdlIngresarEmpleado($tabla, $datos);		
				if($respuesta == "ok"){
					echo '<script>
					swal({
						type: "success",
						title: "¡Datos del Trabajador ha sido guardado correctamente!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){					
							window.location = "empleado";
						}
					});
					</script>';
				}	
			}else{
				echo '<script>
					swal({
						type: "error",
						title: "¡Datos del Trabajador no puede ir vacío o llevar caracteres especiales!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){
							window.location = "empleado";
						}
					});
				</script>';
			}
		}
	}

	static public function ctrMostrarEmpleadoU($item, $valor){

		$tabla = "empleado";

		$respuesta = ModeloEmpleado::MdlMostrarEmpleadoU($tabla, $item, $valor);

		return $respuesta;
	}

	/*=============================================
	MOSTRAR EMPLEADO
	=============================================*/

	static public function ctrMostrarEmpleado($item, $valor){
		$tabla = "empleado";
		$respuesta = ModeloEmpleado::MdlMostrarEmpleado($tabla, $item, $valor);
		return $respuesta;
	}


	/*=============================================
	EDITAR TRABAJADOR
	=============================================*/

	static public function ctrEditarEmpleado(){
		if(isset($_POST["editarNombre"])){
			if(preg_match('/[a-zA-Z0-9 ]/', $_POST["editarNombre"]) &&
				preg_match('/^[0-9]{8}+$/', $_POST["editarDNI"])){
				$tabla = "empleado";			
				$datos = array("dni" => trim($_POST["editarDNI"]),
					           "nombre" =>  strtoupper(trim($_POST["editarNombre"])),
							   "direccion" =>  strtoupper(trim($_POST["editarDireccion"])),
							   "telefono" => trim($_POST["editarTelefono1"]),
							   "email" => filter_var($_POST["editarCorreo"], FILTER_SANITIZE_EMAIL),
							   "fecha_ingreso" => $_POST["editarFecha"],
							   "id_empleado" => $_POST["idTrabajador"],
							   "estado"=>$_POST["estado"]);

				$respuesta = ModeloEmpleado::mdlEditarEmpleado($tabla, $datos);
				if($respuesta == "ok"){
					echo'<script>
					swal({
						  type: "success",
						  title: "Los Datos del Trabajador ha sido editado correctamente",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
									if (result.value) {
									window.location = "empleado";									
									}
							})
					</script>';		
				}
			}else{

				echo'<script>

					swal({
						  type: "error",
						  title: "¡El nombre no puede ir vacío o llevar caracteres especiales!",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
							if (result.value) {

							window.location = "empleado";

							}
						})

			  	</script>';

			}

		}

	}

	/*=============================================
	BORRAR USUARIO
	=============================================*/

	static public function ctrBorrarEmpleado(){
		if(isset($_GET["idTrabajador"])){
			$tabla ="empleado";
			$datos = $_GET["idTrabajador"];
			$respuesta = ModeloEmpleado::mdlBorrarEmpleado($tabla, $datos);
			if($respuesta == "ok"){

				echo'<script>

				swal({
					  type: "success",
					  title: "Empleado ha sido borrado correctamente",
					  showConfirmButton: true,
					  confirmButtonText: "Cerrar"
					  }).then(function(result){
								if (result.value) {

								window.location = "empleado";

								}
							})

				</script>';

			}		

		}

	}


}